@@ -61,7 +61,7 @@ def gql_query(query):
     return response
 
 
-def get_video(video_id):
+def get_video_legacy(video_id):
     """
     https://dev.twitch.tv/docs/v5/reference/videos#get-video
     """
@@ -70,29 +70,61 @@ def get_video(video_id):
     return kraken_get(url).json()
 
 
+VIDEO_FIELDS = """
+    id
+    title
+    publishedAt
+    broadcastType
+    lengthSeconds
+    game {
+        name
+    }
+    creator {
+        login
+        displayName
+    }
+"""
+
+
+def get_video(video_id):
+    query = """
+    {{
+        video(id: "{video_id}") {{
+            {fields}
+        }}
+    }}
+    """
+
+    query = query.format(video_id=video_id, fields=VIDEO_FIELDS)
+
+    response = gql_query(query)
+    return response["data"]["video"]
+
+
 def get_clip(slug):
     query = """
     {{
         clip(slug: "{}") {{
             id
+            slug
             title
             createdAt
+            viewCount
             durationSeconds
-            game {{
-                name
-            }}
-            broadcaster {{
-                login
-                displayName
-                channel {{
-                  name
-                }}
-            }}
+            url
             videoQualities {{
                 frameRate
                 quality
                 sourceURL
             }}
+            game {{
+                id
+                name
+            }}
+            broadcaster {{
+                displayName
+                login
+            }}
         }}
     }}
     """
@@ -139,10 +171,8 @@ def get_channel_clips(channel_id, period, limit, after=None):
                 name
               }}
               broadcaster {{
-                channel {{
-                  name
-                  displayName
-                }}
+                displayName
+                login
               }}
             }}
           }}
@@ -213,9 +243,8 @@ def get_channel_videos(channel_id, limit, sort, type="archive", game_ids=[], aft
                             name
                         }}
                         creator {{
-                            channel {{
-                                displayName
-                            }}
+                            login
+                            displayName
                         }}
                     }}
                 }}
@@ -256,9 +285,26 @@ def channel_videos_generator(channel_id, limit, sort, type, game_ids=None):
 
 
 def get_access_token(video_id):
-    url = "https://api.twitch.tv/api/vods/{}/access_token".format(video_id)
+    query = """
+    {{
+        videoPlaybackAccessToken(
+            id: {video_id},
+            params: {{
+                platform: "web",
+                playerBackend: "mediaplayer",
+                playerType: "site"
+            }}
+        ) {{
+            signature
+            value
+        }}
+    }}
+    """
 
-    return authenticated_get(url).json()
+    query = query.format(video_id=video_id)
+
+    response = gql_query(query)
+    return response["data"]["videoPlaybackAccessToken"]
 
 
 def get_playlists(video_id, access_token):
@@ -268,8 +314,8 @@ def get_playlists(video_id, access_token):
     url = "http://usher.twitch.tv/vod/{}".format(video_id)
 
     response = requests.get(url, params={
-        "nauth": access_token['token'],
-        "nauthsig": access_token['sig'],
+        "nauth": access_token['value'],
+        "nauthsig": access_token['signature'],
         "allow_source": "true",
         "player": "twitchweb",
     })
